@@ -220,7 +220,7 @@ void KateMainWindow::setupMainWindow ()
 
   m_viewManager = new KateViewManager (centralWidget(), this);
 
-  KateMDI::ToolView *ft = createToolView("kate_filelist", KMultiTabBar::Left, SmallIcon("kmultiple"), i18n("Documents"));
+  KateMDI::ToolView *ft = createToolView("kate_filelist", KMultiTabBar::Left, SmallIcon("document-multiple"), i18n("Documents"));
   m_fileList = new KateFileList(ft, actionCollection());
   m_documentModel = new KateViewDocumentProxyModel(this);
   m_documentModel->setSourceModel(KateDocManager::self());
@@ -268,14 +268,14 @@ void KateMainWindow::setupActions()
   actionCollection()->addAction(fileOpenRecent->objectName(), fileOpenRecent);
   fileOpenRecent->setWhatsThis(i18n("This lists files which you have opened recently, and allows you to easily open them again."));
 
-  a = static_cast<KAction*>(actionCollection()->addAction( "file_save_all" ));
+  a = actionCollection()->addAction( "file_save_all" );
   a->setIcon( KIcon("document-save-all") );
   a->setText( i18n("Save A&ll") );
   a->setShortcut( QKeySequence(Qt::CTRL + Qt::Key_L) );
   connect( a, SIGNAL( triggered() ), KateDocManager::self(), SLOT( saveAll() ) );
   a->setWhatsThis(i18n("Save all open, modified documents to disk."));
 
-  a = static_cast<KAction*>(actionCollection()->addAction( "file_reload_all" ));
+  a = actionCollection()->addAction( "file_reload_all" );
   a->setText( i18n("&Reload All") );
   connect( a, SIGNAL( triggered() ), KateDocManager::self(), SLOT( reloadAll() ) );
   a->setWhatsThis(i18n("Reload all open documents."));
@@ -283,12 +283,12 @@ void KateMainWindow::setupActions()
   actionCollection()->addAction( KStandardAction::Close, "file_close", m_viewManager, SLOT( slotDocumentClose() ) )
   ->setWhatsThis(i18n("Close the current document."));
 
-  a = static_cast<KAction*>(actionCollection()->addAction( "file_close_other" ));
+  a = actionCollection()->addAction( "file_close_other" );
   a->setText( i18n( "Close Other" ) );
   connect( a, SIGNAL( triggered() ), this, SLOT( slotDocumentCloseOther() ) );
   a->setWhatsThis(i18n("Close other open documents."));
 
-  a = static_cast<KAction*>(actionCollection()->addAction( "file_close_all" ));
+  a = actionCollection()->addAction( "file_close_all" );
   a->setText( i18n( "Clos&e All" ) );
   connect( a, SIGNAL( triggered() ), this, SLOT( slotDocumentCloseAll() ) );
   a->setWhatsThis(i18n("Close all open documents."));
@@ -296,7 +296,7 @@ void KateMainWindow::setupActions()
   actionCollection()->addAction( KStandardAction::Quit, "file_quit", this, SLOT( slotFileQuit() ) )
   ->setWhatsThis(i18n("Close this window"));
 
-  a = static_cast<KAction*>(actionCollection()->addAction( "view_new_view" ));
+  a = actionCollection()->addAction( "view_new_view" );
   a->setIcon( KIcon("window-new") );
   a->setText( i18n("&New Window") );
   connect( a, SIGNAL( triggered() ), this, SLOT( newWindow() ) );
@@ -312,11 +312,11 @@ void KateMainWindow::setupActions()
   connect(documentOpenWith->menu(), SIGNAL(aboutToShow()), this, SLOT(mSlotFixOpenWithMenu()));
   connect(documentOpenWith->menu(), SIGNAL(triggered(QAction*)), this, SLOT(slotOpenWithMenuAction(QAction*)));
 
-  a = static_cast<KAction*>(actionCollection()->addAction(KStandardAction::KeyBindings, this, SLOT(editKeys())));
+  a = actionCollection()->addAction(KStandardAction::KeyBindings, this, SLOT(editKeys()));
   a->setWhatsThis(i18n("Configure the application's keyboard shortcut assignments."));
 
-  a = static_cast<KAction*>(actionCollection()->addAction(KStandardAction::ConfigureToolbars, "set_configure_toolbars",
-                                    this, SLOT(slotEditToolbars())));
+  a = actionCollection()->addAction(KStandardAction::ConfigureToolbars, "set_configure_toolbars",
+                                    this, SLOT(slotEditToolbars()));
   a->setWhatsThis(i18n("Configure which items should appear in the toolbar(s)."));
 
   QAction* settingsConfigure = actionCollection()->addAction(KStandardAction::Preferences, "settings_configure",
@@ -329,16 +329,16 @@ void KateMainWindow::setupActions()
 
   if (KatePluginManager::self()->pluginList().count() > 0)
   {
-    a = static_cast<KAction*>(actionCollection()->addAction( "help_plugins_contents" ));
+    a = actionCollection()->addAction( "help_plugins_contents" );
     a->setText( i18n("&Plugins Handbook") );
     connect( a, SIGNAL( triggered() ), this, SLOT( pluginHelp() ) );
     a->setWhatsThis(i18n("This shows help files for various available plugins."));
   }
 
-  a = static_cast<KAction*>(actionCollection()->addAction( "help_about_editor" ));
+  a = actionCollection()->addAction( "help_about_editor" );
   a->setText( i18n("&About Editor Component") );
   connect( a, SIGNAL( triggered() ), this, SLOT( aboutEditor() ) );
-  qobject_cast<KAction*>( a )->setGlobalShortcutAllowed(true);
+  a->setGlobalShortcutAllowed(true);
 
   connect(m_viewManager, SIGNAL(viewChanged()), m_mainWindow, SIGNAL(viewChanged()));
   connect(m_viewManager, SIGNAL(viewChanged()), this, SLOT(slotWindowActivated()));
@@ -347,27 +347,27 @@ void KateMainWindow::setupActions()
   slotWindowActivated ();
 
   // session actions
-  a = static_cast<KAction*>(actionCollection()->addAction( "sessions_new" ));
+  a = actionCollection()->addAction( "sessions_new" );
   a->setIcon( KIcon("document-new") );
   a->setText( i18nc("Menu entry Session->New", "&New") );
   connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionNew() ) );
-  a = static_cast<KAction*>(actionCollection()->addAction( "sessions_open" ));
+  a = actionCollection()->addAction( "sessions_open" );
   a->setIcon( KIcon("document-open") );
   a->setText( i18n("&Open...") );
   connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionOpen() ) );
-  a = static_cast<KAction*>(actionCollection()->addAction( "sessions_save" ));
+  a = actionCollection()->addAction( "sessions_save" );
   a->setIcon( KIcon("document-save") );
   a->setText( i18n("&Save") );
   connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionSave() ) );
-  a = static_cast<KAction*>(actionCollection()->addAction( "sessions_save_as" ));
+  a = actionCollection()->addAction( "sessions_save_as" );
   a->setIcon( KIcon("document-save-as") );
   a->setText( i18n("Save &As...") );
   connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionSaveAs() ) );
-  a = static_cast<KAction*>(actionCollection()->addAction( "sessions_save_default" ));
+  a = actionCollection()->addAction( "sessions_save_default" );
   a->setIcon( KIcon("document-save-as") );
   a->setText( i18n("Save As &Default...") );
   connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionSaveAsDefault() ) );
-  a = static_cast<KAction*>(actionCollection()->addAction( "sessions_manage" ));
+  a = actionCollection()->addAction( "sessions_manage" );
   a->setIcon( KIcon("view-choose") );
   a->setText( i18n("&Manage...") );
   connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionManage() ) );
@@ -671,6 +671,10 @@ void KateMainWindow::slotConfigure()
   dlg->exec();
 
   delete dlg;
+
+  m_viewManager->reactivateActiveView(); // gui (toolbars...) needs to be updated, because
+                                         // of possible changes that the configure dialog
+                                         // could have done on it, specially for plugins.
 }
 
 KUrl KateMainWindow::activeDocumentUrl()
@@ -763,10 +767,7 @@ void KateMainWindow::tipOfTheDay()
 
 void KateMainWindow::slotFullScreen(bool t)
 {
-  if (t)
-    showFullScreen();
-  else
-    showNormal();
+  KToggleFullScreenAction::setFullScreen(this, t);
 }
 
 bool KateMainWindow::event( QEvent *e )
@@ -869,12 +870,15 @@ void KateMainWindow::saveProperties(KConfigGroup& config)
   m_viewManager->saveViewConfiguration (config);
 }
 
-void KateMainWindow::readProperties(KConfigGroup config)
+void KateMainWindow::readProperties(const KConfigGroup& config)
 {
-  startRestore(config.config(), config.name());
+  // TODO startRestore should take a const KConfigBase*, or even just a const KConfigGroup&,
+  // but this propagates down to interfaces/kate/plugin.h so all plugins have to be ported
+  KConfigBase* configBase = const_cast<KConfig *>(config.config());
+  startRestore(configBase, config.name());
 
   // perhaps enable plugin guis
-  KatePluginManager::self()->enableAllPluginsGUI (this, config.config());
+  KatePluginManager::self()->enableAllPluginsGUI (this, configBase);
 
   finishRestore ();
 
